// Copyright 2014 Google Inc. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

// Handler for /static content.

package static

import (
	"io/ioutil"
	"fmt"
	"mime"
	"net/http"
	"net/url"
	"path"

	"k8s.io/klog"
)

const StaticResource = "/static/"

var popper, _ = Asset("pages/assets/js/popper.min.js")
var containersJs, _ = Asset("pages/assets/js/containers.js")

var containersCss, _ = Asset("pages/assets/styles/containers.css")

var staticFiles = map[string][]byte{
	"containers.css":                 containersCss,
	"containers.js":                  containersJs,
}

var localFiles = map[string]string{
	"popper.min.js":                   "/usr/share/javascript/popper.js",
	"bootstrap-4.0.0-beta.2.min.css":  "/usr/share/javascript/bootstrap/css/bootstrap.min.css",
	"bootstrap-4.0.0-beta.2.min.js":   "/usr/share/javascript/bootstrap/js/bootstrap.min.js",
	"bootstrap-theme-3.1.1.min.css":   "/usr/share/javascript/bootstrap/css/bootstrap-theme.min.css",
	"jquery-3.0.0.min.js":             "/usr/share/javascript/jquery/jquery.min.js",
}

func HandleRequest(w http.ResponseWriter, u *url.URL) {
	if len(u.Path) <= len(StaticResource) {
		http.Error(w, fmt.Sprintf("unknown static resource %q", u.Path), http.StatusNotFound)
		return
	}

	// Get the static content if it exists.
	resource := u.Path[len(StaticResource):]
	content, ok := staticFiles[resource]
	if !ok {
		contentFilename, ok := localFiles[resource]
		if !ok {
			http.Error(w, fmt.Sprintf("unknown static resource %q", u.Path), http.StatusNotFound)
			return
		}
		content, _ = ioutil.ReadFile(contentFilename)
	}

	// Set Content-Type if we were able to detect it.
	contentType := mime.TypeByExtension(path.Ext(resource))
	if contentType != "" {
		w.Header().Set("Content-Type", contentType)
	}

	if _, err := w.Write(content); err != nil {
		klog.Errorf("Failed to write response: %v", err)
	}
}
